@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,12 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.documentai_v1beta2.types import geometry
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -65,13 +62,11 @@ class BatchProcessDocumentsRequest(proto.Message):
     requests = proto.RepeatedField(
         proto.MESSAGE, number=1, message="ProcessDocumentRequest",
     )
-
-    parent = proto.Field(proto.STRING, number=2)
+    parent = proto.Field(proto.STRING, number=2,)
 
 
 class ProcessDocumentRequest(proto.Message):
     r"""Request to process one document.
-
     Attributes:
         parent (str):
             Target project and location to make a call.
@@ -114,28 +109,20 @@ class ProcessDocumentRequest(proto.Message):
             Params.
     """
 
-    parent = proto.Field(proto.STRING, number=9)
-
+    parent = proto.Field(proto.STRING, number=9,)
     input_config = proto.Field(proto.MESSAGE, number=1, message="InputConfig",)
-
     output_config = proto.Field(proto.MESSAGE, number=2, message="OutputConfig",)
-
-    document_type = proto.Field(proto.STRING, number=3)
-
+    document_type = proto.Field(proto.STRING, number=3,)
     table_extraction_params = proto.Field(
         proto.MESSAGE, number=4, message="TableExtractionParams",
     )
-
     form_extraction_params = proto.Field(
         proto.MESSAGE, number=5, message="FormExtractionParams",
     )
-
     entity_extraction_params = proto.Field(
         proto.MESSAGE, number=6, message="EntityExtractionParams",
     )
-
     ocr_params = proto.Field(proto.MESSAGE, number=7, message="OcrParams",)
-
     automl_params = proto.Field(proto.MESSAGE, number=8, message="AutoMlParams",)
 
 
@@ -155,7 +142,6 @@ class BatchProcessDocumentsResponse(proto.Message):
 
 class ProcessDocumentResponse(proto.Message):
     r"""Response to a single document processing request.
-
     Attributes:
         input_config (google.cloud.documentai_v1beta2.types.InputConfig):
             Information about the input file. This is the
@@ -168,7 +154,6 @@ class ProcessDocumentResponse(proto.Message):
     """
 
     input_config = proto.Field(proto.MESSAGE, number=1, message="InputConfig",)
-
     output_config = proto.Field(proto.MESSAGE, number=2, message="OutputConfig",)
 
 
@@ -189,12 +174,11 @@ class OcrParams(proto.Message):
             specified languages is not one of the supported languages.
     """
 
-    language_hints = proto.RepeatedField(proto.STRING, number=1)
+    language_hints = proto.RepeatedField(proto.STRING, number=1,)
 
 
 class TableExtractionParams(proto.Message):
     r"""Parameters to control table extraction behavior.
-
     Attributes:
         enabled (bool):
             Whether to enable table extraction.
@@ -212,15 +196,12 @@ class TableExtractionParams(proto.Message):
             "builtin/latest" for the latest model.
     """
 
-    enabled = proto.Field(proto.BOOL, number=1)
-
+    enabled = proto.Field(proto.BOOL, number=1,)
     table_bound_hints = proto.RepeatedField(
         proto.MESSAGE, number=2, message="TableBoundHint",
     )
-
-    header_hints = proto.RepeatedField(proto.STRING, number=3)
-
-    model_version = proto.Field(proto.STRING, number=4)
+    header_hints = proto.RepeatedField(proto.STRING, number=3,)
+    model_version = proto.Field(proto.STRING, number=4,)
 
 
 class TableBoundHint(proto.Message):
@@ -239,14 +220,12 @@ class TableBoundHint(proto.Message):
             axis-aligned rectangle.
     """
 
-    page_number = proto.Field(proto.INT32, number=1)
-
+    page_number = proto.Field(proto.INT32, number=1,)
     bounding_box = proto.Field(proto.MESSAGE, number=2, message=geometry.BoundingPoly,)
 
 
 class FormExtractionParams(proto.Message):
     r"""Parameters to control form extraction behavior.
-
     Attributes:
         enabled (bool):
             Whether to enable form extraction.
@@ -274,18 +253,15 @@ class FormExtractionParams(proto.Message):
             are stored.
     """
 
-    enabled = proto.Field(proto.BOOL, number=1)
-
+    enabled = proto.Field(proto.BOOL, number=1,)
     key_value_pair_hints = proto.RepeatedField(
         proto.MESSAGE, number=2, message="KeyValuePairHint",
     )
-
-    model_version = proto.Field(proto.STRING, number=3)
+    model_version = proto.Field(proto.STRING, number=3,)
 
 
 class KeyValuePairHint(proto.Message):
     r"""User-provided hint for key value pair.
-
     Attributes:
         key (str):
             The key text for the hint.
@@ -296,14 +272,12 @@ class KeyValuePairHint(proto.Message):
             Types not in this list will be ignored.
     """
 
-    key = proto.Field(proto.STRING, number=1)
-
-    value_types = proto.RepeatedField(proto.STRING, number=2)
+    key = proto.Field(proto.STRING, number=1,)
+    value_types = proto.RepeatedField(proto.STRING, number=2,)
 
 
 class EntityExtractionParams(proto.Message):
     r"""Parameters to control entity extraction behavior.
-
     Attributes:
         enabled (bool):
             Whether to enable entity extraction.
@@ -313,14 +287,12 @@ class EntityExtractionParams(proto.Message):
             "builtin/latest" for the latest model.
     """
 
-    enabled = proto.Field(proto.BOOL, number=1)
-
-    model_version = proto.Field(proto.STRING, number=2)
+    enabled = proto.Field(proto.BOOL, number=1,)
+    model_version = proto.Field(proto.STRING, number=2,)
 
 
 class AutoMlParams(proto.Message):
     r"""Parameters to control AutoML model prediction behavior.
-
     Attributes:
         model (str):
             Resource name of the AutoML model.
@@ -329,12 +301,11 @@ class AutoMlParams(proto.Message):
             ``projects/{project-id}/locations/{location-id}/models/{model-id}``.
     """
 
-    model = proto.Field(proto.STRING, number=1)
+    model = proto.Field(proto.STRING, number=1,)
 
 
 class InputConfig(proto.Message):
     r"""The desired input location and metadata.
-
     Attributes:
         gcs_source (google.cloud.documentai_v1beta2.types.GcsSource):
             The Google Cloud Storage location to read the
@@ -359,15 +330,12 @@ class InputConfig(proto.Message):
     gcs_source = proto.Field(
         proto.MESSAGE, number=1, oneof="source", message="GcsSource",
     )
-
-    contents = proto.Field(proto.BYTES, number=3, oneof="source")
-
-    mime_type = proto.Field(proto.STRING, number=2)
+    contents = proto.Field(proto.BYTES, number=3, oneof="source",)
+    mime_type = proto.Field(proto.STRING, number=2,)
 
 
 class OutputConfig(proto.Message):
     r"""The desired output location and metadata.
-
     Attributes:
         gcs_destination (google.cloud.documentai_v1beta2.types.GcsDestination):
             The Google Cloud Storage location to write
@@ -395,8 +363,7 @@ class OutputConfig(proto.Message):
     gcs_destination = proto.Field(
         proto.MESSAGE, number=1, oneof="destination", message="GcsDestination",
     )
-
-    pages_per_shard = proto.Field(proto.INT32, number=2)
+    pages_per_shard = proto.Field(proto.INT32, number=2,)
 
 
 class GcsSource(proto.Message):
@@ -408,7 +375,7 @@ class GcsSource(proto.Message):
 
     """
 
-    uri = proto.Field(proto.STRING, number=1)
+    uri = proto.Field(proto.STRING, number=1,)
 
 
 class GcsDestination(proto.Message):
@@ -420,12 +387,11 @@ class GcsDestination(proto.Message):
 
     """
 
-    uri = proto.Field(proto.STRING, number=1)
+    uri = proto.Field(proto.STRING, number=1,)
 
 
 class OperationMetadata(proto.Message):
     r"""Contains metadata for the BatchProcessDocuments operation.
-
     Attributes:
         state (google.cloud.documentai_v1beta2.types.OperationMetadata.State):
             The state of the current batch processing.
@@ -449,12 +415,9 @@ class OperationMetadata(proto.Message):
         FAILED = 6
 
     state = proto.Field(proto.ENUM, number=1, enum=State,)
-
-    state_message = proto.Field(proto.STRING, number=2)
-
-    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
-
-    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp.Timestamp,)
+    state_message = proto.Field(proto.STRING, number=2,)
+    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
+    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
