@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,17 +20,16 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.documentai_v1beta3.types import document
 from google.cloud.documentai_v1beta3.types import document_processor_service
-
 from .transports.base import DocumentProcessorServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import DocumentProcessorServiceGrpcAsyncIOTransport
 from .client import DocumentProcessorServiceClient
@@ -61,33 +58,28 @@ class DocumentProcessorServiceAsyncClient:
     parse_processor_path = staticmethod(
         DocumentProcessorServiceClient.parse_processor_path
     )
-
     common_billing_account_path = staticmethod(
         DocumentProcessorServiceClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         DocumentProcessorServiceClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(DocumentProcessorServiceClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         DocumentProcessorServiceClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         DocumentProcessorServiceClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         DocumentProcessorServiceClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(
         DocumentProcessorServiceClient.common_project_path
     )
     parse_common_project_path = staticmethod(
         DocumentProcessorServiceClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(
         DocumentProcessorServiceClient.common_location_path
     )
@@ -97,7 +89,8 @@ class DocumentProcessorServiceAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -112,7 +105,7 @@ class DocumentProcessorServiceAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -129,7 +122,7 @@ class DocumentProcessorServiceAsyncClient:
 
     @property
     def transport(self) -> DocumentProcessorServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             DocumentProcessorServiceTransport: The transport used by the client instance.
@@ -144,12 +137,12 @@ class DocumentProcessorServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, DocumentProcessorServiceTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the document processor service client.
+        """Instantiates the document processor service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -181,7 +174,6 @@ class DocumentProcessorServiceAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = DocumentProcessorServiceClient(
             credentials=credentials,
             transport=transport,
@@ -211,7 +203,6 @@ class DocumentProcessorServiceAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -238,7 +229,6 @@ class DocumentProcessorServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -251,7 +241,8 @@ class DocumentProcessorServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=120.0,
             ),
@@ -294,7 +285,6 @@ class DocumentProcessorServiceAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -324,7 +314,6 @@ class DocumentProcessorServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -337,7 +326,8 @@ class DocumentProcessorServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=120.0,
             ),
@@ -389,7 +379,6 @@ class DocumentProcessorServiceAsyncClient:
                 This corresponds to the ``human_review_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -419,7 +408,6 @@ class DocumentProcessorServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if human_review_config is not None:
             request.human_review_config = human_review_config
 
@@ -432,7 +420,8 @@ class DocumentProcessorServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=120.0,
             ),
