@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,18 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.documentai_v1beta3.types import geometry
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-from google.rpc import status_pb2 as status  # type: ignore
-from google.type import color_pb2 as gt_color  # type: ignore
-from google.type import date_pb2 as date  # type: ignore
-from google.type import datetime_pb2 as datetime  # type: ignore
-from google.type import money_pb2 as money  # type: ignore
-from google.type import postal_address_pb2 as postal_address  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+from google.rpc import status_pb2  # type: ignore
+from google.type import color_pb2  # type: ignore
+from google.type import date_pb2  # type: ignore
+from google.type import datetime_pb2  # type: ignore
+from google.type import money_pb2  # type: ignore
+from google.type import postal_address_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -107,11 +104,9 @@ class Document(proto.Message):
                 in the overall document global text.
         """
 
-        shard_index = proto.Field(proto.INT64, number=1)
-
-        shard_count = proto.Field(proto.INT64, number=2)
-
-        text_offset = proto.Field(proto.INT64, number=3)
+        shard_index = proto.Field(proto.INT64, number=1,)
+        shard_count = proto.Field(proto.INT64, number=2,)
+        text_offset = proto.Field(proto.INT64, number=3,)
 
     class Style(proto.Message):
         r"""Annotation for common text style attributes. This adheres to
@@ -140,7 +135,6 @@ class Document(proto.Message):
 
         class FontSize(proto.Message):
             r"""Font size with unit.
-
             Attributes:
                 size (float):
                     Font size for the text.
@@ -149,31 +143,25 @@ class Document(proto.Message):
                     (in, px, pt, etc.).
             """
 
-            size = proto.Field(proto.FLOAT, number=1)
-
-            unit = proto.Field(proto.STRING, number=2)
+            size = proto.Field(proto.FLOAT, number=1,)
+            unit = proto.Field(proto.STRING, number=2,)
 
         text_anchor = proto.Field(
             proto.MESSAGE, number=1, message="Document.TextAnchor",
         )
-
-        color = proto.Field(proto.MESSAGE, number=2, message=gt_color.Color,)
-
-        background_color = proto.Field(proto.MESSAGE, number=3, message=gt_color.Color,)
-
-        font_weight = proto.Field(proto.STRING, number=4)
-
-        text_style = proto.Field(proto.STRING, number=5)
-
-        text_decoration = proto.Field(proto.STRING, number=6)
-
+        color = proto.Field(proto.MESSAGE, number=2, message=color_pb2.Color,)
+        background_color = proto.Field(
+            proto.MESSAGE, number=3, message=color_pb2.Color,
+        )
+        font_weight = proto.Field(proto.STRING, number=4,)
+        text_style = proto.Field(proto.STRING, number=5,)
+        text_decoration = proto.Field(proto.STRING, number=6,)
         font_size = proto.Field(
             proto.MESSAGE, number=7, message="Document.Style.FontSize",
         )
 
     class Page(proto.Message):
         r"""A page in a [Document][google.cloud.documentai.v1beta3.Document].
-
         Attributes:
             page_number (int):
                 1-based index for current
@@ -228,7 +216,6 @@ class Document(proto.Message):
 
         class Dimension(proto.Message):
             r"""Dimension for the page.
-
             Attributes:
                 width (float):
                     Page width.
@@ -238,15 +225,12 @@ class Document(proto.Message):
                     Dimension unit.
             """
 
-            width = proto.Field(proto.FLOAT, number=1)
-
-            height = proto.Field(proto.FLOAT, number=2)
-
-            unit = proto.Field(proto.STRING, number=3)
+            width = proto.Field(proto.FLOAT, number=1,)
+            height = proto.Field(proto.FLOAT, number=2,)
+            unit = proto.Field(proto.STRING, number=3,)
 
         class Image(proto.Message):
             r"""Rendered image contents for this page.
-
             Attributes:
                 content (bytes):
                     Raw byte content of the image.
@@ -258,13 +242,10 @@ class Document(proto.Message):
                     Height of the image in pixels.
             """
 
-            content = proto.Field(proto.BYTES, number=1)
-
-            mime_type = proto.Field(proto.STRING, number=2)
-
-            width = proto.Field(proto.INT32, number=3)
-
-            height = proto.Field(proto.INT32, number=4)
+            content = proto.Field(proto.BYTES, number=1,)
+            mime_type = proto.Field(proto.STRING, number=2,)
+            width = proto.Field(proto.INT32, number=3,)
+            height = proto.Field(proto.INT32, number=4,)
 
         class Matrix(proto.Message):
             r"""Representation for transformation matrix, intended to be
@@ -285,17 +266,13 @@ class Document(proto.Message):
                     The matrix data.
             """
 
-            rows = proto.Field(proto.INT32, number=1)
-
-            cols = proto.Field(proto.INT32, number=2)
-
-            type_ = proto.Field(proto.INT32, number=3)
-
-            data = proto.Field(proto.BYTES, number=4)
+            rows = proto.Field(proto.INT32, number=1,)
+            cols = proto.Field(proto.INT32, number=2,)
+            type_ = proto.Field(proto.INT32, number=3,)
+            data = proto.Field(proto.BYTES, number=4,)
 
         class Layout(proto.Message):
             r"""Visual element describing a layout unit on a page.
-
             Attributes:
                 text_anchor (google.cloud.documentai_v1beta3.types.Document.TextAnchor):
                     Text anchor indexing into the
@@ -325,13 +302,10 @@ class Document(proto.Message):
             text_anchor = proto.Field(
                 proto.MESSAGE, number=1, message="Document.TextAnchor",
             )
-
-            confidence = proto.Field(proto.FLOAT, number=2)
-
+            confidence = proto.Field(proto.FLOAT, number=2,)
             bounding_poly = proto.Field(
                 proto.MESSAGE, number=3, message=geometry.BoundingPoly,
             )
-
             orientation = proto.Field(
                 proto.ENUM, number=4, enum="Document.Page.Layout.Orientation",
             )
@@ -355,11 +329,9 @@ class Document(proto.Message):
             layout = proto.Field(
                 proto.MESSAGE, number=1, message="Document.Page.Layout",
             )
-
             detected_languages = proto.RepeatedField(
                 proto.MESSAGE, number=2, message="Document.Page.DetectedLanguage",
             )
-
             provenance = proto.Field(
                 proto.MESSAGE, number=3, message="Document.Provenance",
             )
@@ -383,11 +355,9 @@ class Document(proto.Message):
             layout = proto.Field(
                 proto.MESSAGE, number=1, message="Document.Page.Layout",
             )
-
             detected_languages = proto.RepeatedField(
                 proto.MESSAGE, number=2, message="Document.Page.DetectedLanguage",
             )
-
             provenance = proto.Field(
                 proto.MESSAGE, number=3, message="Document.Provenance",
             )
@@ -412,18 +382,15 @@ class Document(proto.Message):
             layout = proto.Field(
                 proto.MESSAGE, number=1, message="Document.Page.Layout",
             )
-
             detected_languages = proto.RepeatedField(
                 proto.MESSAGE, number=2, message="Document.Page.DetectedLanguage",
             )
-
             provenance = proto.Field(
                 proto.MESSAGE, number=3, message="Document.Provenance",
             )
 
         class Token(proto.Message):
             r"""A detected token.
-
             Attributes:
                 layout (google.cloud.documentai_v1beta3.types.Document.Page.Layout):
                     [Layout][google.cloud.documentai.v1beta3.Document.Page.Layout]
@@ -462,15 +429,12 @@ class Document(proto.Message):
             layout = proto.Field(
                 proto.MESSAGE, number=1, message="Document.Page.Layout",
             )
-
             detected_break = proto.Field(
                 proto.MESSAGE, number=2, message="Document.Page.Token.DetectedBreak",
             )
-
             detected_languages = proto.RepeatedField(
                 proto.MESSAGE, number=3, message="Document.Page.DetectedLanguage",
             )
-
             provenance = proto.Field(
                 proto.MESSAGE, number=4, message="Document.Provenance",
             )
@@ -495,16 +459,13 @@ class Document(proto.Message):
             layout = proto.Field(
                 proto.MESSAGE, number=1, message="Document.Page.Layout",
             )
-
-            type_ = proto.Field(proto.STRING, number=2)
-
+            type_ = proto.Field(proto.STRING, number=2,)
             detected_languages = proto.RepeatedField(
                 proto.MESSAGE, number=3, message="Document.Page.DetectedLanguage",
             )
 
         class Table(proto.Message):
             r"""A table representation similar to HTML table structure.
-
             Attributes:
                 layout (google.cloud.documentai_v1beta3.types.Document.Page.Layout):
                     [Layout][google.cloud.documentai.v1beta3.Document.Page.Layout]
@@ -521,7 +482,6 @@ class Document(proto.Message):
 
             class TableRow(proto.Message):
                 r"""A row of table cells.
-
                 Attributes:
                     cells (Sequence[google.cloud.documentai_v1beta3.types.Document.Page.Table.TableCell]):
                         Cells that make up this row.
@@ -533,7 +493,6 @@ class Document(proto.Message):
 
             class TableCell(proto.Message):
                 r"""A cell representation inside the table.
-
                 Attributes:
                     layout (google.cloud.documentai_v1beta3.types.Document.Page.Layout):
                         [Layout][google.cloud.documentai.v1beta3.Document.Page.Layout]
@@ -551,11 +510,8 @@ class Document(proto.Message):
                 layout = proto.Field(
                     proto.MESSAGE, number=1, message="Document.Page.Layout",
                 )
-
-                row_span = proto.Field(proto.INT32, number=2)
-
-                col_span = proto.Field(proto.INT32, number=3)
-
+                row_span = proto.Field(proto.INT32, number=2,)
+                col_span = proto.Field(proto.INT32, number=3,)
                 detected_languages = proto.RepeatedField(
                     proto.MESSAGE, number=4, message="Document.Page.DetectedLanguage",
                 )
@@ -563,22 +519,18 @@ class Document(proto.Message):
             layout = proto.Field(
                 proto.MESSAGE, number=1, message="Document.Page.Layout",
             )
-
             header_rows = proto.RepeatedField(
                 proto.MESSAGE, number=2, message="Document.Page.Table.TableRow",
             )
-
             body_rows = proto.RepeatedField(
                 proto.MESSAGE, number=3, message="Document.Page.Table.TableRow",
             )
-
             detected_languages = proto.RepeatedField(
                 proto.MESSAGE, number=4, message="Document.Page.DetectedLanguage",
             )
 
         class FormField(proto.Message):
             r"""A form field detected on the page.
-
             Attributes:
                 field_name (google.cloud.documentai_v1beta3.types.Document.Page.Layout):
                     [Layout][google.cloud.documentai.v1beta3.Document.Page.Layout]
@@ -609,24 +561,19 @@ class Document(proto.Message):
             field_name = proto.Field(
                 proto.MESSAGE, number=1, message="Document.Page.Layout",
             )
-
             field_value = proto.Field(
                 proto.MESSAGE, number=2, message="Document.Page.Layout",
             )
-
             name_detected_languages = proto.RepeatedField(
                 proto.MESSAGE, number=3, message="Document.Page.DetectedLanguage",
             )
-
             value_detected_languages = proto.RepeatedField(
                 proto.MESSAGE, number=4, message="Document.Page.DetectedLanguage",
             )
-
-            value_type = proto.Field(proto.STRING, number=5)
+            value_type = proto.Field(proto.STRING, number=5,)
 
         class DetectedLanguage(proto.Message):
             r"""Detected language for a structural component.
-
             Attributes:
                 language_code (str):
                     The BCP-47 language code, such as "en-US" or "sr-Latn". For
@@ -636,52 +583,39 @@ class Document(proto.Message):
                     Confidence of detected language. Range [0, 1].
             """
 
-            language_code = proto.Field(proto.STRING, number=1)
-
-            confidence = proto.Field(proto.FLOAT, number=2)
-
-        page_number = proto.Field(proto.INT32, number=1)
+            language_code = proto.Field(proto.STRING, number=1,)
+            confidence = proto.Field(proto.FLOAT, number=2,)
 
+        page_number = proto.Field(proto.INT32, number=1,)
         image = proto.Field(proto.MESSAGE, number=13, message="Document.Page.Image",)
-
         transforms = proto.RepeatedField(
             proto.MESSAGE, number=14, message="Document.Page.Matrix",
         )
-
         dimension = proto.Field(
             proto.MESSAGE, number=2, message="Document.Page.Dimension",
         )
-
         layout = proto.Field(proto.MESSAGE, number=3, message="Document.Page.Layout",)
-
         detected_languages = proto.RepeatedField(
             proto.MESSAGE, number=4, message="Document.Page.DetectedLanguage",
         )
-
         blocks = proto.RepeatedField(
             proto.MESSAGE, number=5, message="Document.Page.Block",
         )
-
         paragraphs = proto.RepeatedField(
             proto.MESSAGE, number=6, message="Document.Page.Paragraph",
         )
-
         lines = proto.RepeatedField(
             proto.MESSAGE, number=7, message="Document.Page.Line",
         )
-
         tokens = proto.RepeatedField(
             proto.MESSAGE, number=8, message="Document.Page.Token",
         )
-
         visual_elements = proto.RepeatedField(
             proto.MESSAGE, number=9, message="Document.Page.VisualElement",
         )
-
         tables = proto.RepeatedField(
             proto.MESSAGE, number=10, message="Document.Page.Table",
         )
-
         form_fields = proto.RepeatedField(
             proto.MESSAGE, number=11, message="Document.Page.FormField",
         )
@@ -731,7 +665,6 @@ class Document(proto.Message):
 
         class NormalizedValue(proto.Message):
             r"""Parsed and normalized entity value.
-
             Attributes:
                 money_value (google.type.money_pb2.Money):
                     Money value. See also:
@@ -765,62 +698,53 @@ class Document(proto.Message):
             """
 
             money_value = proto.Field(
-                proto.MESSAGE, number=2, oneof="structured_value", message=money.Money,
+                proto.MESSAGE,
+                number=2,
+                oneof="structured_value",
+                message=money_pb2.Money,
             )
-
             date_value = proto.Field(
-                proto.MESSAGE, number=3, oneof="structured_value", message=date.Date,
+                proto.MESSAGE,
+                number=3,
+                oneof="structured_value",
+                message=date_pb2.Date,
             )
-
             datetime_value = proto.Field(
                 proto.MESSAGE,
                 number=4,
                 oneof="structured_value",
-                message=datetime.DateTime,
+                message=datetime_pb2.DateTime,
             )
-
             address_value = proto.Field(
                 proto.MESSAGE,
                 number=5,
                 oneof="structured_value",
-                message=postal_address.PostalAddress,
+                message=postal_address_pb2.PostalAddress,
             )
-
-            boolean_value = proto.Field(proto.BOOL, number=6, oneof="structured_value")
-
-            text = proto.Field(proto.STRING, number=1)
+            boolean_value = proto.Field(proto.BOOL, number=6, oneof="structured_value",)
+            text = proto.Field(proto.STRING, number=1,)
 
         text_anchor = proto.Field(
             proto.MESSAGE, number=1, message="Document.TextAnchor",
         )
-
-        type_ = proto.Field(proto.STRING, number=2)
-
-        mention_text = proto.Field(proto.STRING, number=3)
-
-        mention_id = proto.Field(proto.STRING, number=4)
-
-        confidence = proto.Field(proto.FLOAT, number=5)
-
+        type_ = proto.Field(proto.STRING, number=2,)
+        mention_text = proto.Field(proto.STRING, number=3,)
+        mention_id = proto.Field(proto.STRING, number=4,)
+        confidence = proto.Field(proto.FLOAT, number=5,)
         page_anchor = proto.Field(
             proto.MESSAGE, number=6, message="Document.PageAnchor",
         )
-
-        id = proto.Field(proto.STRING, number=7)
-
+        id = proto.Field(proto.STRING, number=7,)
         normalized_value = proto.Field(
             proto.MESSAGE, number=9, message="Document.Entity.NormalizedValue",
         )
-
         properties = proto.RepeatedField(
             proto.MESSAGE, number=10, message="Document.Entity",
         )
-
         provenance = proto.Field(
             proto.MESSAGE, number=11, message="Document.Provenance",
         )
-
-        redacted = proto.Field(proto.BOOL, number=12)
+        redacted = proto.Field(proto.BOOL, number=12,)
 
     class EntityRelation(proto.Message):
         r"""Relationship between
@@ -835,11 +759,9 @@ class Document(proto.Message):
                 Relationship description.
         """
 
-        subject_id = proto.Field(proto.STRING, number=1)
-
-        object_id = proto.Field(proto.STRING, number=2)
-
-        relation = proto.Field(proto.STRING, number=3)
+        subject_id = proto.Field(proto.STRING, number=1,)
+        object_id = proto.Field(proto.STRING, number=2,)
+        relation = proto.Field(proto.STRING, number=3,)
 
     class TextAnchor(proto.Message):
         r"""Text reference indexing into the
@@ -872,15 +794,13 @@ class Document(proto.Message):
                     [Document.text][google.cloud.documentai.v1beta3.Document.text].
             """
 
-            start_index = proto.Field(proto.INT64, number=1)
-
-            end_index = proto.Field(proto.INT64, number=2)
+            start_index = proto.Field(proto.INT64, number=1,)
+            end_index = proto.Field(proto.INT64, number=2,)
 
         text_segments = proto.RepeatedField(
             proto.MESSAGE, number=1, message="Document.TextAnchor.TextSegment",
         )
-
-        content = proto.Field(proto.STRING, number=2)
+        content = proto.Field(proto.STRING, number=2,)
 
     class PageAnchor(proto.Message):
         r"""Referencing the visual context of the entity in the
@@ -914,6 +834,9 @@ class Document(proto.Message):
                 bounding_poly (google.cloud.documentai_v1beta3.types.BoundingPoly):
                     Optional. Identifies the bounding polygon of
                     a layout element on the page.
+                confidence (float):
+                    Optional. Confidence of detected page element, if
+                    applicable. Range [0, 1].
             """
 
             class LayoutType(proto.Enum):
@@ -927,17 +850,15 @@ class Document(proto.Message):
                 TABLE = 6
                 FORM_FIELD = 7
 
-            page = proto.Field(proto.INT64, number=1)
-
+            page = proto.Field(proto.INT64, number=1,)
             layout_type = proto.Field(
                 proto.ENUM, number=2, enum="Document.PageAnchor.PageRef.LayoutType",
             )
-
-            layout_id = proto.Field(proto.STRING, number=3)
-
+            layout_id = proto.Field(proto.STRING, number=3,)
             bounding_poly = proto.Field(
                 proto.MESSAGE, number=4, message=geometry.BoundingPoly,
             )
+            confidence = proto.Field(proto.FLOAT, number=5,)
 
         page_refs = proto.RepeatedField(
             proto.MESSAGE, number=1, message="Document.PageAnchor.PageRef",
@@ -986,25 +907,20 @@ class Document(proto.Message):
                     The id of the parent provenance.
             """
 
-            revision = proto.Field(proto.INT32, number=1)
-
-            id = proto.Field(proto.INT32, number=2)
-
-        revision = proto.Field(proto.INT32, number=1)
-
-        id = proto.Field(proto.INT32, number=2)
+            revision = proto.Field(proto.INT32, number=1,)
+            id = proto.Field(proto.INT32, number=2,)
 
+        revision = proto.Field(proto.INT32, number=1,)
+        id = proto.Field(proto.INT32, number=2,)
         parents = proto.RepeatedField(
             proto.MESSAGE, number=3, message="Document.Provenance.Parent",
         )
-
         type_ = proto.Field(
             proto.ENUM, number=4, enum="Document.Provenance.OperationType",
         )
 
     class Revision(proto.Message):
         r"""Contains past or forward revisions of this document.
-
         Attributes:
             agent (str):
                 If the change was made by a person specify
@@ -1027,7 +943,6 @@ class Document(proto.Message):
 
         class HumanReview(proto.Message):
             r"""Human Review information of the document.
-
             Attributes:
                 state (str):
                     Human review state. e.g. ``requested``, ``succeeded``,
@@ -1038,27 +953,22 @@ class Document(proto.Message):
                     is ``rejected``.
             """
 
-            state = proto.Field(proto.STRING, number=1)
-
-            state_message = proto.Field(proto.STRING, number=2)
-
-        agent = proto.Field(proto.STRING, number=4, oneof="source")
-
-        processor = proto.Field(proto.STRING, number=5, oneof="source")
-
-        id = proto.Field(proto.STRING, number=1)
-
-        parent = proto.RepeatedField(proto.INT32, number=2)
-
-        create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
+            state = proto.Field(proto.STRING, number=1,)
+            state_message = proto.Field(proto.STRING, number=2,)
 
+        agent = proto.Field(proto.STRING, number=4, oneof="source",)
+        processor = proto.Field(proto.STRING, number=5, oneof="source",)
+        id = proto.Field(proto.STRING, number=1,)
+        parent = proto.RepeatedField(proto.INT32, number=2,)
+        create_time = proto.Field(
+            proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,
+        )
         human_review = proto.Field(
             proto.MESSAGE, number=6, message="Document.Revision.HumanReview",
         )
 
     class TextChange(proto.Message):
         r"""This message is used for text changes aka. OCR corrections.
-
         Attributes:
             text_anchor (google.cloud.documentai_v1beta3.types.Document.TextAnchor):
                 Provenance of the correction. Text anchor indexing into the
@@ -1076,37 +986,24 @@ class Document(proto.Message):
         text_anchor = proto.Field(
             proto.MESSAGE, number=1, message="Document.TextAnchor",
         )
-
-        changed_text = proto.Field(proto.STRING, number=2)
-
+        changed_text = proto.Field(proto.STRING, number=2,)
         provenance = proto.RepeatedField(
             proto.MESSAGE, number=3, message="Document.Provenance",
         )
 
-    uri = proto.Field(proto.STRING, number=1, oneof="source")
-
-    content = proto.Field(proto.BYTES, number=2, oneof="source")
-
-    mime_type = proto.Field(proto.STRING, number=3)
-
-    text = proto.Field(proto.STRING, number=4)
-
+    uri = proto.Field(proto.STRING, number=1, oneof="source",)
+    content = proto.Field(proto.BYTES, number=2, oneof="source",)
+    mime_type = proto.Field(proto.STRING, number=3,)
+    text = proto.Field(proto.STRING, number=4,)
     text_styles = proto.RepeatedField(proto.MESSAGE, number=5, message=Style,)
-
     pages = proto.RepeatedField(proto.MESSAGE, number=6, message=Page,)
-
     entities = proto.RepeatedField(proto.MESSAGE, number=7, message=Entity,)
-
     entity_relations = proto.RepeatedField(
         proto.MESSAGE, number=8, message=EntityRelation,
     )
-
     text_changes = proto.RepeatedField(proto.MESSAGE, number=14, message=TextChange,)
-
     shard_info = proto.Field(proto.MESSAGE, number=9, message=ShardInfo,)
-
-    error = proto.Field(proto.MESSAGE, number=10, message=status.Status,)
-
+    error = proto.Field(proto.MESSAGE, number=10, message=status_pb2.Status,)
     revisions = proto.RepeatedField(proto.MESSAGE, number=13, message=Revision,)
 
 
