@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,9 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import os
 import mock
+import packaging.version
 
 import grpc
 from grpc.experimental import aio
@@ -24,16 +23,16 @@ import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
 
-from google import auth
+
 from google.api_core import client_options
-from google.api_core import exceptions
+from google.api_core import exceptions as core_exceptions
 from google.api_core import future
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
 from google.api_core import operation_async  # type: ignore
 from google.api_core import operations_v1
-from google.auth import credentials
+from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.documentai_v1beta2.services.document_understanding_service import (
     DocumentUnderstandingServiceAsyncClient,
@@ -44,12 +43,42 @@ from google.cloud.documentai_v1beta2.services.document_understanding_service imp
 from google.cloud.documentai_v1beta2.services.document_understanding_service import (
     transports,
 )
+from google.cloud.documentai_v1beta2.services.document_understanding_service.transports.base import (
+    _API_CORE_VERSION,
+)
+from google.cloud.documentai_v1beta2.services.document_understanding_service.transports.base import (
+    _GOOGLE_AUTH_VERSION,
+)
 from google.cloud.documentai_v1beta2.types import document
 from google.cloud.documentai_v1beta2.types import document_understanding
 from google.cloud.documentai_v1beta2.types import geometry
 from google.longrunning import operations_pb2
 from google.oauth2 import service_account
-from google.rpc import status_pb2 as status  # type: ignore
+from google.rpc import status_pb2  # type: ignore
+import google.auth
+
+
+# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
+# - Delete all the api-core and auth "less than" test cases
+# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
+requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth < 1.25.0",
+)
+requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth >= 1.25.0",
+)
+
+requires_api_core_lt_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core < 1.26.0",
+)
+
+requires_api_core_gte_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core >= 1.26.0",
+)
 
 
 def client_cert_source_callback():
@@ -104,7 +133,7 @@ def test__get_default_mtls_endpoint():
     [DocumentUnderstandingServiceClient, DocumentUnderstandingServiceAsyncClient,],
 )
 def test_document_understanding_service_client_from_service_account_info(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
@@ -122,7 +151,7 @@ def test_document_understanding_service_client_from_service_account_info(client_
     [DocumentUnderstandingServiceClient, DocumentUnderstandingServiceAsyncClient,],
 )
 def test_document_understanding_service_client_from_service_account_file(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
@@ -181,7 +210,7 @@ def test_document_understanding_service_client_client_options(
     with mock.patch.object(
         DocumentUnderstandingServiceClient, "get_transport_class"
     ) as gtc:
-        transport = transport_class(credentials=credentials.AnonymousCredentials())
+        transport = transport_class(credentials=ga_credentials.AnonymousCredentials())
         client = client_class(transport=transport)
         gtc.assert_not_called()
 
@@ -490,7 +519,7 @@ def test_batch_process_documents(
     request_type=document_understanding.BatchProcessDocumentsRequest,
 ):
     client = DocumentUnderstandingServiceClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -503,13 +532,11 @@ def test_batch_process_documents(
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = operations_pb2.Operation(name="operations/spam")
-
         response = client.batch_process_documents(request)
 
         # Establish that the underlying gRPC stub method was called.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == document_understanding.BatchProcessDocumentsRequest()
 
     # Establish that the response is the type that we expect.
@@ -524,7 +551,7 @@ def test_batch_process_documents_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DocumentUnderstandingServiceClient(
-        credentials=credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -534,7 +561,6 @@ def test_batch_process_documents_empty_call():
         client.batch_process_documents()
         call.assert_called()
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == document_understanding.BatchProcessDocumentsRequest()
 
 
@@ -544,7 +570,7 @@ async def test_batch_process_documents_async(
     request_type=document_understanding.BatchProcessDocumentsRequest,
 ):
     client = DocumentUnderstandingServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -559,13 +585,11 @@ async def test_batch_process_documents_async(
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             operations_pb2.Operation(name="operations/spam")
         )
-
         response = await client.batch_process_documents(request)
 
         # Establish that the underlying gRPC stub method was called.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == document_understanding.BatchProcessDocumentsRequest()
 
     # Establish that the response is the type that we expect.
@@ -579,12 +603,13 @@ async def test_batch_process_documents_async_from_dict():
 
 def test_batch_process_documents_field_headers():
     client = DocumentUnderstandingServiceClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = document_understanding.BatchProcessDocumentsRequest()
+
     request.parent = "parent/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -592,7 +617,6 @@ def test_batch_process_documents_field_headers():
         type(client.transport.batch_process_documents), "__call__"
     ) as call:
         call.return_value = operations_pb2.Operation(name="operations/op")
-
         client.batch_process_documents(request)
 
         # Establish that the underlying gRPC stub method was called.
@@ -608,12 +632,13 @@ def test_batch_process_documents_field_headers():
 @pytest.mark.asyncio
 async def test_batch_process_documents_field_headers_async():
     client = DocumentUnderstandingServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = document_understanding.BatchProcessDocumentsRequest()
+
     request.parent = "parent/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -623,7 +648,6 @@ async def test_batch_process_documents_field_headers_async():
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             operations_pb2.Operation(name="operations/op")
         )
-
         await client.batch_process_documents(request)
 
         # Establish that the underlying gRPC stub method was called.
@@ -638,7 +662,7 @@ async def test_batch_process_documents_field_headers_async():
 
 def test_batch_process_documents_flattened():
     client = DocumentUnderstandingServiceClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -647,7 +671,6 @@ def test_batch_process_documents_flattened():
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = operations_pb2.Operation(name="operations/op")
-
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         client.batch_process_documents(
@@ -660,7 +683,6 @@ def test_batch_process_documents_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-
         assert args[0].requests == [
             document_understanding.ProcessDocumentRequest(parent="parent_value")
         ]
@@ -668,7 +690,7 @@ def test_batch_process_documents_flattened():
 
 def test_batch_process_documents_flattened_error():
     client = DocumentUnderstandingServiceClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Attempting to call a method with both a request object and flattened
@@ -685,7 +707,7 @@ def test_batch_process_documents_flattened_error():
 @pytest.mark.asyncio
 async def test_batch_process_documents_flattened_async():
     client = DocumentUnderstandingServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -710,7 +732,6 @@ async def test_batch_process_documents_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-
         assert args[0].requests == [
             document_understanding.ProcessDocumentRequest(parent="parent_value")
         ]
@@ -719,7 +740,7 @@ async def test_batch_process_documents_flattened_async():
 @pytest.mark.asyncio
 async def test_batch_process_documents_flattened_error_async():
     client = DocumentUnderstandingServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Attempting to call a method with both a request object and flattened
@@ -737,7 +758,7 @@ def test_process_document(
     transport: str = "grpc", request_type=document_understanding.ProcessDocumentRequest
 ):
     client = DocumentUnderstandingServiceClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -750,21 +771,16 @@ def test_process_document(
         call.return_value = document.Document(
             mime_type="mime_type_value", text="text_value", uri="uri_value",
         )
-
         response = client.process_document(request)
 
         # Establish that the underlying gRPC stub method was called.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == document_understanding.ProcessDocumentRequest()
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, document.Document)
-
     assert response.mime_type == "mime_type_value"
-
     assert response.text == "text_value"
 
 
@@ -776,7 +792,7 @@ def test_process_document_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DocumentUnderstandingServiceClient(
-        credentials=credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -784,7 +800,6 @@ def test_process_document_empty_call():
         client.process_document()
         call.assert_called()
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == document_understanding.ProcessDocumentRequest()
 
 
@@ -794,7 +809,7 @@ async def test_process_document_async(
     request_type=document_understanding.ProcessDocumentRequest,
 ):
     client = DocumentUnderstandingServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -807,20 +822,16 @@ async def test_process_document_async(
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             document.Document(mime_type="mime_type_value", text="text_value",)
         )
-
         response = await client.process_document(request)
 
         # Establish that the underlying gRPC stub method was called.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == document_understanding.ProcessDocumentRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, document.Document)
-
     assert response.mime_type == "mime_type_value"
-
     assert response.text == "text_value"
 
 
@@ -831,18 +842,18 @@ async def test_process_document_async_from_dict():
 
 def test_process_document_field_headers():
     client = DocumentUnderstandingServiceClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = document_understanding.ProcessDocumentRequest()
+
     request.parent = "parent/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.process_document), "__call__") as call:
         call.return_value = document.Document()
-
         client.process_document(request)
 
         # Establish that the underlying gRPC stub method was called.
@@ -858,18 +869,18 @@ def test_process_document_field_headers():
 @pytest.mark.asyncio
 async def test_process_document_field_headers_async():
     client = DocumentUnderstandingServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = document_understanding.ProcessDocumentRequest()
+
     request.parent = "parent/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.process_document), "__call__") as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(document.Document())
-
         await client.process_document(request)
 
         # Establish that the underlying gRPC stub method was called.
@@ -885,16 +896,16 @@ async def test_process_document_field_headers_async():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.DocumentUnderstandingServiceGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = DocumentUnderstandingServiceClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
     transport = transports.DocumentUnderstandingServiceGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = DocumentUnderstandingServiceClient(
@@ -904,7 +915,7 @@ def test_credentials_transport_error():
 
     # It is an error to provide scopes and a transport instance.
     transport = transports.DocumentUnderstandingServiceGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = DocumentUnderstandingServiceClient(
@@ -915,7 +926,7 @@ def test_credentials_transport_error():
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.DocumentUnderstandingServiceGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     client = DocumentUnderstandingServiceClient(transport=transport)
     assert client.transport is transport
@@ -924,13 +935,13 @@ def test_transport_instance():
 def test_transport_get_channel():
     # A client may be instantiated with a custom transport instance.
     transport = transports.DocumentUnderstandingServiceGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     channel = transport.grpc_channel
     assert channel
 
     transport = transports.DocumentUnderstandingServiceGrpcAsyncIOTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     channel = transport.grpc_channel
     assert channel
@@ -945,8 +956,8 @@ def test_transport_get_channel():
 )
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default") as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport_class()
         adc.assert_called_once()
 
@@ -954,7 +965,7 @@ def test_transport_adc(transport_class):
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
     client = DocumentUnderstandingServiceClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     assert isinstance(
         client.transport, transports.DocumentUnderstandingServiceGrpcTransport,
@@ -963,9 +974,9 @@ def test_transport_grpc_default():
 
 def test_document_understanding_service_base_transport_error():
     # Passing both a credentials object and credentials_file should raise an error
-    with pytest.raises(exceptions.DuplicateCredentialArgs):
+    with pytest.raises(core_exceptions.DuplicateCredentialArgs):
         transport = transports.DocumentUnderstandingServiceTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
             credentials_file="credentials.json",
         )
 
@@ -977,7 +988,7 @@ def test_document_understanding_service_base_transport():
     ) as Transport:
         Transport.return_value = None
         transport = transports.DocumentUnderstandingServiceTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
         )
 
     # Every method on the transport should just blindly
@@ -996,15 +1007,37 @@ def test_document_understanding_service_base_transport():
         transport.operations_client
 
 
+@requires_google_auth_gte_1_25_0
 def test_document_understanding_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
-        auth, "load_credentials_from_file"
+        google.auth, "load_credentials_from_file", autospec=True
     ) as load_creds, mock.patch(
         "google.cloud.documentai_v1beta2.services.document_understanding_service.transports.DocumentUnderstandingServiceTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport = transports.DocumentUnderstandingServiceTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=None,
+            default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            quota_project_id="octopus",
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_document_understanding_service_base_transport_with_credentials_file_old_google_auth():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch(
+        "google.cloud.documentai_v1beta2.services.document_understanding_service.transports.DocumentUnderstandingServiceTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.DocumentUnderstandingServiceTransport(
             credentials_file="credentials.json", quota_project_id="octopus",
         )
@@ -1017,19 +1050,33 @@ def test_document_understanding_service_base_transport_with_credentials_file():
 
 def test_document_understanding_service_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
-    with mock.patch.object(auth, "default") as adc, mock.patch(
+    with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
         "google.cloud.documentai_v1beta2.services.document_understanding_service.transports.DocumentUnderstandingServiceTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.DocumentUnderstandingServiceTransport()
         adc.assert_called_once()
 
 
+@requires_google_auth_gte_1_25_0
 def test_document_understanding_service_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        DocumentUnderstandingServiceClient()
+        adc.assert_called_once_with(
+            scopes=None,
+            default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            quota_project_id=None,
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_document_understanding_service_auth_adc_old_google_auth():
+    # If no credentials are provided, we should use ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         DocumentUnderstandingServiceClient()
         adc.assert_called_once_with(
             scopes=("https://www.googleapis.com/auth/cloud-platform",),
@@ -1037,20 +1084,169 @@ def test_document_understanding_service_auth_adc():
         )
 
 
-def test_document_understanding_service_transport_auth_adc():
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.DocumentUnderstandingServiceGrpcTransport,
+        transports.DocumentUnderstandingServiceGrpcAsyncIOTransport,
+    ],
+)
+@requires_google_auth_gte_1_25_0
+def test_document_understanding_service_transport_auth_adc(transport_class):
     # If credentials and host are not provided, the transport class should use
     # ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
-        transports.DocumentUnderstandingServiceGrpcTransport(
-            host="squid.clam.whelk", quota_project_id="octopus"
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport_class(quota_project_id="octopus", scopes=["1", "2"])
+        adc.assert_called_once_with(
+            scopes=["1", "2"],
+            default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            quota_project_id="octopus",
         )
+
+
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.DocumentUnderstandingServiceGrpcTransport,
+        transports.DocumentUnderstandingServiceGrpcAsyncIOTransport,
+    ],
+)
+@requires_google_auth_lt_1_25_0
+def test_document_understanding_service_transport_auth_adc_old_google_auth(
+    transport_class,
+):
+    # If credentials and host are not provided, the transport class should use
+    # ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport_class(quota_project_id="octopus")
         adc.assert_called_once_with(
             scopes=("https://www.googleapis.com/auth/cloud-platform",),
             quota_project_id="octopus",
         )
 
 
+@pytest.mark.parametrize(
+    "transport_class,grpc_helpers",
+    [
+        (transports.DocumentUnderstandingServiceGrpcTransport, grpc_helpers),
+        (
+            transports.DocumentUnderstandingServiceGrpcAsyncIOTransport,
+            grpc_helpers_async,
+        ),
+    ],
+)
+@requires_api_core_gte_1_26_0
+def test_document_understanding_service_transport_create_channel(
+    transport_class, grpc_helpers
+):
+    # If credentials and host are not provided, the transport class should use
+    # ADC credentials.
+    with mock.patch.object(
+        google.auth, "default", autospec=True
+    ) as adc, mock.patch.object(
+        grpc_helpers, "create_channel", autospec=True
+    ) as create_channel:
+        creds = ga_credentials.AnonymousCredentials()
+        adc.return_value = (creds, None)
+        transport_class(quota_project_id="octopus", scopes=["1", "2"])
+
+        create_channel.assert_called_with(
+            "us-documentai.googleapis.com:443",
+            credentials=creds,
+            credentials_file=None,
+            quota_project_id="octopus",
+            default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            scopes=["1", "2"],
+            default_host="us-documentai.googleapis.com",
+            ssl_credentials=None,
+            options=[
+                ("grpc.max_send_message_length", -1),
+                ("grpc.max_receive_message_length", -1),
+            ],
+        )
+
+
+@pytest.mark.parametrize(
+    "transport_class,grpc_helpers",
+    [
+        (transports.DocumentUnderstandingServiceGrpcTransport, grpc_helpers),
+        (
+            transports.DocumentUnderstandingServiceGrpcAsyncIOTransport,
+            grpc_helpers_async,
+        ),
+    ],
+)
+@requires_api_core_lt_1_26_0
+def test_document_understanding_service_transport_create_channel_old_api_core(
+    transport_class, grpc_helpers
+):
+    # If credentials and host are not provided, the transport class should use
+    # ADC credentials.
+    with mock.patch.object(
+        google.auth, "default", autospec=True
+    ) as adc, mock.patch.object(
+        grpc_helpers, "create_channel", autospec=True
+    ) as create_channel:
+        creds = ga_credentials.AnonymousCredentials()
+        adc.return_value = (creds, None)
+        transport_class(quota_project_id="octopus")
+
+        create_channel.assert_called_with(
+            "us-documentai.googleapis.com:443",
+            credentials=creds,
+            credentials_file=None,
+            quota_project_id="octopus",
+            scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            ssl_credentials=None,
+            options=[
+                ("grpc.max_send_message_length", -1),
+                ("grpc.max_receive_message_length", -1),
+            ],
+        )
+
+
+@pytest.mark.parametrize(
+    "transport_class,grpc_helpers",
+    [
+        (transports.DocumentUnderstandingServiceGrpcTransport, grpc_helpers),
+        (
+            transports.DocumentUnderstandingServiceGrpcAsyncIOTransport,
+            grpc_helpers_async,
+        ),
+    ],
+)
+@requires_api_core_lt_1_26_0
+def test_document_understanding_service_transport_create_channel_user_scopes(
+    transport_class, grpc_helpers
+):
+    # If credentials and host are not provided, the transport class should use
+    # ADC credentials.
+    with mock.patch.object(
+        google.auth, "default", autospec=True
+    ) as adc, mock.patch.object(
+        grpc_helpers, "create_channel", autospec=True
+    ) as create_channel:
+        creds = ga_credentials.AnonymousCredentials()
+        adc.return_value = (creds, None)
+
+        transport_class(quota_project_id="octopus", scopes=["1", "2"])
+
+        create_channel.assert_called_with(
+            "us-documentai.googleapis.com:443",
+            credentials=creds,
+            credentials_file=None,
+            quota_project_id="octopus",
+            scopes=["1", "2"],
+            ssl_credentials=None,
+            options=[
+                ("grpc.max_send_message_length", -1),
+                ("grpc.max_receive_message_length", -1),
+            ],
+        )
+
+
 @pytest.mark.parametrize(
     "transport_class",
     [
@@ -1061,7 +1257,7 @@ def test_document_understanding_service_transport_auth_adc():
 def test_document_understanding_service_grpc_transport_client_cert_source_for_mtls(
     transport_class,
 ):
-    cred = credentials.AnonymousCredentials()
+    cred = ga_credentials.AnonymousCredentials()
 
     # Check ssl_channel_credentials is used if provided.
     with mock.patch.object(transport_class, "create_channel") as mock_create_channel:
@@ -1100,7 +1296,7 @@ def test_document_understanding_service_grpc_transport_client_cert_source_for_mt
 
 def test_document_understanding_service_host_no_port():
     client = DocumentUnderstandingServiceClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="us-documentai.googleapis.com"
         ),
@@ -1110,7 +1306,7 @@ def test_document_understanding_service_host_no_port():
 
 def test_document_understanding_service_host_with_port():
     client = DocumentUnderstandingServiceClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="us-documentai.googleapis.com:8000"
         ),
@@ -1166,9 +1362,9 @@ def test_document_understanding_service_transport_channel_mtls_with_client_cert_
             mock_grpc_channel = mock.Mock()
             grpc_create_channel.return_value = mock_grpc_channel
 
-            cred = credentials.AnonymousCredentials()
+            cred = ga_credentials.AnonymousCredentials()
             with pytest.warns(DeprecationWarning):
-                with mock.patch.object(auth, "default") as adc:
+                with mock.patch.object(google.auth, "default") as adc:
                     adc.return_value = (cred, None)
                     transport = transport_class(
                         host="squid.clam.whelk",
@@ -1246,7 +1442,7 @@ def test_document_understanding_service_transport_channel_mtls_with_adc(
 
 def test_document_understanding_service_grpc_lro_client():
     client = DocumentUnderstandingServiceClient(
-        credentials=credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
     )
     transport = client.transport
 
@@ -1259,7 +1455,7 @@ def test_document_understanding_service_grpc_lro_client():
 
 def test_document_understanding_service_grpc_lro_async_client():
     client = DocumentUnderstandingServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
     )
     transport = client.transport
 
@@ -1272,7 +1468,6 @@ def test_document_understanding_service_grpc_lro_async_client():
 
 def test_common_billing_account_path():
     billing_account = "squid"
-
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1295,7 +1490,6 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-
     expected = "folders/{folder}".format(folder=folder,)
     actual = DocumentUnderstandingServiceClient.common_folder_path(folder)
     assert expected == actual
@@ -1314,7 +1508,6 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-
     expected = "organizations/{organization}".format(organization=organization,)
     actual = DocumentUnderstandingServiceClient.common_organization_path(organization)
     assert expected == actual
@@ -1333,7 +1526,6 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-
     expected = "projects/{project}".format(project=project,)
     actual = DocumentUnderstandingServiceClient.common_project_path(project)
     assert expected == actual
@@ -1353,7 +1545,6 @@ def test_parse_common_project_path():
 def test_common_location_path():
     project = "winkle"
     location = "nautilus"
-
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1380,7 +1571,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.DocumentUnderstandingServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = DocumentUnderstandingServiceClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1389,6 +1580,6 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = DocumentUnderstandingServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
